"""
****************************************
 * @author: Xin Zhang
 * Date: 7/2/21
****************************************
"""

categorical_dictionary = {
    'activation': [
        'relu', "sigmoid", "softmax", "softplus", "softsign", "tanh", "selu", "elu", "exponential"
    ],
    'optimizer': ["sgd", "rmsprop", "adam", "adadelta", "adagrad", "adamax", "nadam", "ftrl"],
    'loss': ["mae", "mape", "mse", "msle", "poisson", "categorical_crossentropy"],
    'use_bias': [True, False]
}
"""
'fillna_method' is for other layers without this property, what to fill in (we can put 0, None or whatever we need)
'use_name' is to change the original name if needed, since maybe we want to merge dense units and conv filters as one feature
'feature_status' is to use or not use this feature, with this we don't have to remove or delete items in this dictionary, just give a flag
"""


def value_grab(x):
    return x


def list_grab(x):
    return x[1]


def dict_grab(x):
    return x['class_name']


layer_feature_dictionary = {
    'Dense': [(
        'units', {
            'data_type': 'numerical',
            'fillna_method': None,
            'use_name': 'units',
            'feature_status': 1,
            'value_type': value_grab
        }
    ),
              (
                  'activation', {
                      'data_type': 'categorical',
                      'fillna_method': None,
                      'use_name': 'activation',
                      'feature_status': 0,
                      'value_type': value_grab
                  }
              ),
              (
                  'use_bias', {
                      'data_type': 'categorical',
                      'fillna_method': None,
                      'use_name': 'use_bias',
                      'feature_status': 1,
                      'value_type': value_grab
                  }
              )],
    'Activation': [(
        'activation', {
            'data_type': 'categorical',
            'fillna_method': None,
            'use_name': 'Activation',
            'feature_status': 1,
            'value_type': value_grab
        }
    )],
    'BatchNormalization': [(
        'momentum', {
            'data_type': 'numerical',
            'fillna_method': None,
            'use_name': 'momentum',
            'feature_status': 1,
            'value_type': value_grab
        }
    ),
                           (
                               'epsilon', {
                                   'data_type': 'numerical',
                                   'fillna_method': None,
                                   'use_name': 'epsilon',
                                   'feature_status': 1,
                                   'value_type': value_grab
                               }
                           )],
    'Conv2D': [(
        'filters', {
            'data_type': 'numerical',
            'fillna_method': None,
            'use_name': 'filters',
            'feature_status': 1,
            'value_type': value_grab
        }
    ),
               (
                   'batch_input_shape', {
                       'data_type': 'numerical',
                       'fillna_method': None,
                       'use_name': 'input_shape_size',
                       'feature_status': 1,
                       'value_type': lambda x: x[1]
                   }
               ),
               (
                   'batch_input_shape', {
                       'data_type': 'numerical',
                       'fillna_method': None,
                       'use_name': 'input_shape_channel',
                       'feature_status': 1,
                       'value_type': lambda x: x[3]
                   }
               ),
               (
                   'padding', {
                       'data_type': 'categorical',
                       'fillna_method': None,
                       'use_name': 'padding',
                       'feature_status': 1,
                       'value_type': value_grab
                   }
               ),
               (
                   'kernel_size', {
                       'data_type': 'numerical',
                       'fillna_method': None,
                       'use_name': 'kernel_size',
                       'feature_status': 1,
                       'value_type': lambda x: x[0]
                   }
               ),
               (
                   'strides', {
                       'data_type': 'numerical',
                       'fillna_method': None,
                       'use_name': 'strides',
                       'feature_status': 1,
                       'value_type': lambda x: x[0]
                   }
               ),
               (
                   'use_bias', {
                       'data_type': 'categorical',
                       'fillna_method': None,
                       'use_name': 'use_bias',
                       'feature_status': 1,
                       'value_type': value_grab
                   }
               )],
    'MaxPooling2D': [(
        'pool_size', {
            'data_type': 'numerical',
            'fillna_method': None,
            'use_name': 'pool_size',
            'feature_status': 1,
            'value_type': lambda x: x[0]
        }
    ),
                     (
                         'padding', {
                             'data_type': 'categorical',
                             'fillna_method': None,
                             'use_name': 'padding',
                             'feature_status': 1,
                             'value_type': value_grab
                         }
                     ),
                     (
                         'strides', {
                             'data_type': 'numerical',
                             'fillna_method': None,
                             'use_name': 'strides',
                             'feature_status': 1,
                             'value_type': lambda x: x[0]
                         }
                     )],
    'Dropout': [(
        'rate', {
            'data_type': 'numerical',
            'fillna_method': None,
            'use_name': 'rate',
            'feature_status': 1,
            'value_type': value_grab
        }
    )],
}


class TypeNoMatch(Exception):
    def __init__(self, m):
        self.message = m

    def __str__(self):
        return self.message


def check_layer_feature_dictionary_valid(layer_feature_dictionary):
    # we need to check same feature has same "data_type" and "fillna_method"
    from collections import defaultdict
    feature_data_type = defaultdict(set)
    feature_fillna_method = defaultdict(set)
    for class_n, conf_d in layer_feature_dictionary.items():
        for conf_type, instruct in conf_d:
            if instruct['feature_status']:
                feature_data_type[instruct['use_name']].add(instruct['data_type'])
                feature_fillna_method[instruct['use_name']].add(instruct['fillna_method'])
    for k in feature_data_type.keys():
        data_types = feature_data_type[k]
        fillna_method = feature_fillna_method[k]
        if len(data_types) > 1:
            raise TypeNoMatch(f'use_name "{k}" should have consistant data_type')
        if len(fillna_method) > 1:
            raise TypeNoMatch(f'use_name "{k}" should have consistant fillna_method')
    print('layer_feature_dictionary passed check')


check_layer_feature_dictionary_valid(layer_feature_dictionary)



import nltk
import matplotlib.pyplot as plt
import seaborn as sns
import pandas as pd


def single_label_included_score(y_pred, y_gold):
    """
    this function will computer the score by including
    Example 1:
    y_pred=[1,2,3]
    y_gold=[{4,5},{2,4},{1,3,7}]
    we can see that for position 0, label "1" is not in {4,5}, but for position 1 and 2
    labels "2", "3" are in {2,4} and {1,3,7} respectively, in this case, the overall
    score is 2/3

    Example 2:
    it can also compute the score same way but for each label
    y_pred=[1,2,3,2,3]
    y_gold=[{4,5},{2,4},{1,3,7},{2,6},{4,5}]
    in this case we see that for label "1", it appears once in y_pred, and not in y_gold
    thus accuracy for "1" is 0.
    Similarity, label "2" appears twice in y_pred, and each time it is in y_gold,
    thus accuracy for "2" is 1
    Same way, for "3" is 1/2

    :param y_pred: a list of predicted labels, must be same length as y_gold
    :param y_gold: a list of sets of labels, must be same length as y_pred
    :return:
    total_score: float of the total score calculated by example 1
    label_wise_accuracy: a dictionary,where keys are labels, values are float score of the label
                        calculated by example 2
    """
    assert len(y_pred) == len(y_gold), 'y_pred and y_gold need to have same length'
    count = 0
    label_wise_score = nltk.defaultdict(lambda: nltk.defaultdict(int))
    for index, pred in enumerate(y_pred):
        gold = set(y_gold[index])
        if pred in gold:
            count += 1
            label_wise_score[pred]['total'] += 1
            label_wise_score[pred]['correct'] += 1
        else:
            label_wise_score[pred]['total'] += 1
    label_wise_accuracy = dict()
    for label in label_wise_score.keys():
        try:
            rate = label_wise_score[label]['correct'] / label_wise_score[label]['total']
        except:
            rate = 0
        label_wise_accuracy[label] = rate
    total_score = count / len(y_gold)
    return total_score, label_wise_accuracy


def multiple_label_included_score(y_pred, y_gold, plot_dist=False, figsize=(10, 6)):
    """
    this function will computer the score by including
    Example 1:
    y_pred=[{1,3},{2,8},{3,7}]
    y_gold=[{4,5},{2,4},{1,3,7}]
    we can see that for position 0, label "1" or "3" is not in {4,5}, but for position 1 and 2
    labels "2", "3" and "7" are in {2,4} and {1,3,7} respectively, in this case, the overall
    score is 2/3

    Example 2:
    it can also compute the score same way but for each label
    y_pred=[{1,6},{2,4},{3,9},{2,8},{3,4}]
    y_gold=[{4,5},{2,4},{1,3,7},{2,6},{4,5,10}]
    in this case we see that for label "1", it appears once in y_pred, and not in y_gold
    thus accuracy for "1" is 0.
    Similarity, label "2" appears twice in y_pred, and each time it is in y_gold,
    thus accuracy for "2" is 1
    Same way, for "3" is 1/2, for "4" is 1, for "6" is 0, for "8" and "9" are 0s


    :param y_pred: a list of sets of predicted labels, must be same length as y_gold
    :param y_gold: a list of sets of labels, must be same length as y_pred
    :param plot_dist: boolean, plot for distribution of which prediction of n predictions for each data point
                      gives the correct prediction only apply when all number of predictions are the same,
                      and predictions are in a list not set
    :return:
    total_score: float of the total score calculated by example 1
    label_wise_accuracy: a dictionary,where keys are labels, values are float score of the label
                        calculated by example 2
    """
    assert len(y_pred) == len(y_gold), 'y_pred and y_gold need to have same length'
    count = 0
    num_of_pred = len(y_pred[0])
    plot_dict = dict((i + 1, 0) for i in range(num_of_pred))
    label_wise_score = nltk.defaultdict(lambda: nltk.defaultdict(int))
    for index, pred in enumerate(y_pred):
        pred1 = set(pred)
        gold = set(y_gold[index])
        Intersection = pred1.intersection(gold)
        if Intersection:
            count += 1
        if plot_dist:
            for prediction in Intersection:
                i = pred.index(prediction) + 1
                plot_dict[i] += 1
        for label in pred:
            if label in Intersection:
                label_wise_score[label]['total'] += 1
                label_wise_score[label]['correct'] += 1
            else:
                label_wise_score[label]['total'] += 1
    label_wise_accuracy = dict()
    for label in label_wise_score.keys():
        try:
            rate = label_wise_score[label]['correct'] / label_wise_score[label]['total']
        except:
            rate = 0
        label_wise_accuracy[label] = rate
    total_score = count / len(y_gold)
    if plot_dist:
        data = []
        for position, how_many in plot_dict.items():
            data.append((position, how_many))
        data = sorted(data, key=lambda x: x[0])
        df = pd.DataFrame(data, columns=['position', 'count'])
        sns.set(style="darkgrid")
        plt.figure(figsize=figsize)
        ax = sns.barplot(
            x="position", y="count", data=df, color='lightsalmon', orient='v', saturation=.1
        )
        for p in ax.patches:
            ax.annotate('{0}'.format(int(p.get_height())), (p.get_x() + .35, p.get_height()))
        for item in ax.get_xticklabels():
            item.set_rotation(0)
        plt.title(
            'Count of ith position made the correct prediction. {0} in Total'.format(num_of_pred)
        )
        plt.show()
    return total_score, label_wise_accuracy


def single_label_normal_score(y_pred, y_gold):
    """
    this function will computer the score by simple compare exact or not
    Example 1:
    y_pred=[1,2,3]
    y_gold=[2,2,3]
    score is 2/3

    Example 2:
    it can also compute the score same way but for each label
    y_pred=[1,2,3,2,3]
    y_gold=[2,2,3,1,3]
    in this case we see that for label "1", it appears once in y_pred, and not in y_gold
    thus accuracy for "1" is 0.
    Similarity, label "2" appears twice in y_pred, and once it is in y_gold,
    thus accuracy for "2" is 1/2
    Same way, for "3" is 1

    :param y_pred: a list of labels, must be same length as y_gold
    :param y_gold: a list of labels, must be same length as y_pred
    :return:
    total_score: float of the total score calculated by example 1
    label_wise_accuracy: a dictionary,where keys are labels, values are float score of the label
                        calculated by example 2
    """
    assert len(y_pred) == len(y_gold), 'y_pred and y_gold need to have same length'
    count = 0
    label_wise_score = nltk.defaultdict(lambda: nltk.defaultdict(int))
    for index, pred in enumerate(y_pred):
        gold = y_gold[index]
        if pred == gold:
            count += 1
            label_wise_score[pred]['total'] += 1
            label_wise_score[pred]['correct'] += 1
        else:
            label_wise_score[pred]['total'] += 1
    label_wise_accuracy = dict()
    for label in label_wise_score.keys():
        try:
            rate = label_wise_score[label]['correct'] / label_wise_score[label]['total']
        except:
            rate = 0
        label_wise_accuracy[label] = rate
    total_score = count / len(y_gold)
    return total_score, label_wise_accuracy


def single_label_f_score(y_pred, y_gold):
    """
    this function will computer the F-score
    :param y_pred: a list of labels, must be same length as y_gold
    :param y_gold: a list of labels, must be same length as y_pred
    :return:
    total_score: float of the total score calculated by average all f-scores for all labels
    label_wise_accuracy: a dictionary,where keys are labels, values are float f-score
    """
    assert len(y_pred) == len(y_gold), 'y_pred and y_gold need to have same length'
    Y_P = list(y_pred).copy()
    Y_G = list(y_gold).copy()
    Y_P.extend(Y_G)
    all_labels = set(Y_P)
    label_pairs = []
    for index, pred in enumerate(y_pred):
        label_pairs.append([pred, y_gold[index]])
    labels_pairs_dict = nltk.defaultdict(list)
    for label_ in all_labels:
        for pred, gold in label_pairs:
            if pred == label_ or gold == label_:
                labels_pairs_dict[label_].append((pred, gold))
    labels_f_score = dict()
    for label in labels_pairs_dict.keys():
        FP = 0
        FN = 0
        TP = 0
        pair_list = labels_pairs_dict[label]
        for (pred, gold) in pair_list:
            if pred == label and gold != label:
                FP += 1
            elif pred != label and gold == label:
                FN += 1
            elif pred == label and gold == label:
                TP += 1
        try:
            precision = TP / (TP + FP)
        except:
            precision = 0
        try:
            recall = TP / (TP + FN)
        except:
            recall = 0
        try:
            F_score = 2 * precision * recall / (precision + recall)
        except:
            F_score = 0

        labels_f_score[label] = {'f1': F_score, 'precision': precision, 'recall': recall}

    all_f1 = 0
    all_precision = 0
    all_recall = 0
    for label, scores in labels_f_score.items():
        f1 = scores['f1']
        precision = scores['precision']
        recall = scores['recall']
        all_f1 += f1
        all_precision += precision
        all_recall += recall

    total_score = {
        'f1': all_f1 / len(labels_f_score),
        'precision': all_precision / len(labels_f_score),
        'recall': all_recall / len(labels_f_score)
    }
    return total_score, labels_f_score


def multiple_label_intersection_score(y_pred, y_gold):
    """
    this function will computer the score by including
    Example 1:
    y_pred=[{1,3},{2,8},{3,7,9}]
    y_gold=[{4,5,6},{2,4,8},{1,3,7}]
    we can see that for position 0, the intersection is none, so intersection size is 0,
    and the size of pred is 2, the size of gold is 3, thus the score is (0/2+0/3)/2=0.
    Similarly for position 2 is (2/2+2/3)/2=5/6, for position 3 is (2/3+2/3)/2=2/3

    Example 2:
    it can also compute the score same way but for each label
    y_pred=[{1,6},{2,4},{3,9},{2,8},{3,4}]
    y_gold=[{4,5},{2,4},{1,3,7},{2,6},{4,5,10}]
    in this case we see that for label "1", it appears once in y_pred, and not in y_gold,
    since or appearing has a penalty, we minute score for that. So score for 1 is -1
    Similarity, label "2" appears twice in y_pred, and each time it is in y_gold,
    thus accuracy for "2" is 1+1/2=1
    Same way, for "3" is 1-1/2=0, for "4" is 1+1/2=1, for "6" is -1-1/2=-1, for "8" -1/2=-0.5
    and "9" -1/2=-0.5

    :param y_pred: a list of sets of predicted labels, must be same length as y_gold
    :param y_gold: a list of sets of labels, must be same length as y_pred
    :return:
    total_score: float of the total score calculated by example 1
    label_wise_accuracy: a dictionary,where keys are labels, values are float score of the label
                        calculated by example 2
    """
    assert len(y_pred) == len(y_gold), 'y_pred and y_gold need to have same length'
    label_wise_score = nltk.defaultdict(lambda: nltk.defaultdict(int))
    All_score = []
    for index, pred in enumerate(y_pred):
        pred = set(pred)
        gold = set(y_gold[index])
        Intersection = pred.intersection(gold)
        forward_score = len(Intersection) / len(pred)
        backward_score = len(Intersection) / len(gold)
        score = (backward_score + forward_score) / 2
        All_score.append(score)
        all = pred.union(gold)
        for label in all:
            if label in Intersection:
                label_wise_score[label]['total'] += 1
                label_wise_score[label]['correct'] += 1
            else:
                label_wise_score[label]['total'] += 1
                label_wise_score[label]['correct'] -= 1
    label_wise_accuracy = dict()
    for label in label_wise_score.keys():
        try:
            rate = label_wise_score[label]['correct'] / label_wise_score[label]['total']
        except:
            rate = 0
        label_wise_accuracy[label] = rate
    total_score = sum(All_score) / len(All_score)
    return total_score, label_wise_accuracy



import nltk
import os
import numpy as np
import math
from tqdm import tqdm
import random
# image read libraries
from PIL import Image
import matplotlib.pyplot as plt
import shutil


class obj_to_cls:
    def __init__(
        self,
        images_dir,
        expand_ratio_width=0.1,
        expand_ratio_hight=0.1,
        labels_dir=None,
        filter_diff=True
    ):
        """

        @param images_dir: .jpg format images
        @param extend_ratio: expand the box by ratio (negative means crop more), but don't do negative since image
        augmentation will take care of that. Can bigger than 1
        @param labels_dir: txt format labels
        @param filter_diff: if filter image and label files with name doesn't match
        """
        if labels_dir is None:
            labels_dir = images_dir

        image_path = []
        label_path = []
        image_names = set()
        label_names = set()

        for root, dirs, files in os.walk(images_dir):
            for file in files:
                if file.endswith(".jpg"):
                    if 'checkpoint' in file:
                        pass
                    else:
                        file_path = os.path.join(root, file)
                        image_names.add(os.path.splitext(file_path.split(os.sep)[-1])[0])
                        image_path.append(file_path)

        for root, dirs, files in os.walk(labels_dir):
            for file in files:
                if file.endswith(".txt"):
                    if 'checkpoint' in file:
                        pass
                    else:
                        file_path = os.path.join(root, file)
                        label_names.add(os.path.splitext(file_path.split(os.sep)[-1])[0])
                        label_path.append(file_path)

        common_names = image_names.intersection(label_names)

        if filter_diff:
            image_path = [
                i for i in image_path if os.path.splitext(i.split(os.sep)[-1])[0] in common_names
            ]
            label_path = [
                i for i in label_path if os.path.splitext(i.split(os.sep)[-1])[0] in common_names
            ]

        image_path = sorted(image_path)
        label_path = sorted(label_path)

        self.images_dir = images_dir
        self.labels_dir = labels_dir
        self.image_path = image_path
        self.label_path = label_path
        self.image_label_path_pair = list(zip(image_path, label_path))
        self.expand_ratio_width = expand_ratio_width
        self.expand_ratio_hight = expand_ratio_hight

    @staticmethod
    def create_folder(path, sub_dirs):
        for sub in sub_dirs:
            create_dir = os.path.join(path, sub)
            if os.path.exists(create_dir):
                shutil.rmtree(create_dir)
                os.makedirs(create_dir)
            else:
                os.makedirs(create_dir)

    @staticmethod
    def uniquify(path):
        filename, extension = os.path.splitext(path)
        counter = 1

        while os.path.exists(path):
            path = filename + " (" + str(counter) + ")" + extension
            counter += 1
        return path

    def test_if_unique_data_pairs(self):
        # TEST if any image and label doesn't match
        for ip, lp in self.image_label_path_pair:
            ip_name = '.'.join(ip.split('/')[-1].split('.')[:-1])
            lp_name = '.'.join(lp.split('/')[-1].split('.')[:-1])
            if ip_name == lp_name:
                pass
            else:
                print(ip_name, lp_name)
                print("name doesn't match")

    def convert_to_classification_data(self, new_dir, upsample=True, upsample_rate=0.1, seed=42):
        """
        This function will remain the original directory structure and create label-wise sub-folder,
        if one image has multiple object the save name will be added (1) or (2) etc
        @param self:
        @param new_dir:
        @param upsample:
        @param upsample_rate: what percentage has to be reached for low amount labels compare to the top 1 label
        @return:
        """
        epsilon = 1e-6  # in case of 0 values in x, y, w, h

        all_image_path = []
        for ip in self.image_path:
            ip_idx = ip.split(os.sep).index(self.images_dir.split(os.sep)[-1])
            all_image_path.append(os.path.join(*ip.split(os.sep)[ip_idx + 1:-1]))

        all_label_path = []
        for lp in self.label_path:
            lp_idx = lp.split(os.sep).index(self.labels_dir.split(os.sep)[-1])
            all_label_path.append(os.path.join(*lp.split(os.sep)[lp_idx + 1:-1]))

        all_image_path = list(set(all_image_path))
        all_label_path = list(set(all_label_path))
        obj_to_cls.create_folder(new_dir, all_image_path)

        label_appearance = nltk.defaultdict(int)
        label_shortage = nltk.defaultdict(int)
        label_source = nltk.defaultdict(list)

        for im_p, lb_p in tqdm(self.image_label_path_pair):
            with open(lb_p) as f:
                lines = f.read().splitlines()

            for l in lines:
                line_split = l.split(' ')
                label = int(line_split[0])
                label_appearance[label] += 1

        top_label_count = max(label_appearance.values())
        for label, count in label_appearance.items():
            short_amount = max(int(upsample_rate * top_label_count) - count, 0)
            label_shortage[label] = short_amount

        print('prepare original data...')
        for im_p, lb_p in tqdm(self.image_label_path_pair):
            img = Image.open(im_p)
            img_array = np.array(img)  # convert to np array

            # Note that some pictures doesn't have channel
            try:
                hight, width, channel = img_array.shape
            except:
                hight, width = img_array.shape
            with open(lb_p) as f:
                lines = f.read().splitlines()

            for l in lines:
                line_split = l.split(' ')
                label = int(line_split[0])
                label_appearance[label] += 1
                x, y, w, h = tuple([float(i) + epsilon for i in line_split[1:5]])

                # change crop ratio
                w = (1 + self.expand_ratio_width) * w
                h = (1 + self.expand_ratio_hight) * h

                # take max or min to make sure the crop is within the image
                top_left_x = max(math.floor(x * width - w * width / 2), 0)
                top_left_y = max(math.floor(y * hight - h * hight / 2), 0)
                bot_right_x = min(math.floor(x * width + w * width / 2), width)
                bot_right_y = min(math.floor(y * hight + h * hight / 2), hight)

                label_source[label].append([
                    im_p, [top_left_x, top_left_y, bot_right_x, bot_right_y]
                ])

                img2 = img.crop((top_left_x, top_left_y, bot_right_x, bot_right_y))

                ip_idx = im_p.split(os.sep).index(self.images_dir.split(os.sep)[-1])

                save_dir = os.path.join(new_dir, *im_p.split(os.sep)[1 + ip_idx:-1], f'{label}')
                if os.path.exists(save_dir):
                    pass
                else:
                    os.mkdir(save_dir)
                save_path = obj_to_cls.uniquify(os.path.join(save_dir, im_p.split(os.sep)[-1]))
                img2.save(save_path)

        if upsample:
            print('upsampling data...')
            random.seed(seed)
            for label, short_amount in tqdm(label_shortage.items()):
                sample_source = label_source[label]
                random_source = random.choices(sample_source, k=short_amount)
                for im_p, loaction in random_source:
                    top_left_x, top_left_y, bot_right_x, bot_right_y = loaction[0], loaction[
                        1], loaction[2], loaction[3]
                    img = Image.open(im_p)
                    img2 = img.crop((top_left_x, top_left_y, bot_right_x, bot_right_y))

                    ip_idx = im_p.split(os.sep).index(self.images_dir.split(os.sep)[-1])

                    save_dir = os.path.join(new_dir, *im_p.split(os.sep)[1 + ip_idx:-1], f'{label}')
                    if os.path.exists(save_dir):
                        pass
                    else:
                        os.mkdir(save_dir)
                    save_path = obj_to_cls.uniquify(os.path.join(save_dir, im_p.split(os.sep)[-1]))
                    img2.save(save_path)

        label_final_label_appearance = dict()
        for label, count in label_appearance.items():
            label_final_label_appearance[label] = count + label_shortage[label]

        return label_appearance, label_final_label_appearance


def demo():
    # from object_detect.convert_detection_image_to_classification_image import obj_to_cls
    print('The function will check all files end with .jpg and .txt')
    obj2cls = obj_to_cls('coco128', 'coco128')
    print('check if image and label are 1 to 1')
    obj2cls.test_if_unique_data_pairs()
    obj2cls.convert_to_classification_data('coco128_classification')
